@@ -1,7 +1,7 @@
 from collections.abc import Callable
 from typing import Union
 
-from django_bulk_hooks.enums import Priority
+from django_bulk_hooks.priority import Priority
 
 _hooks: dict[tuple[type, str], list[tuple[type, str, Callable, int]]] = {}
 
@@ -17,7 +17,8 @@ def register_hook(
 
 
 def get_hooks(model, event):
-    return _hooks.get((model, event), [])
+    hooks = _hooks.get((model, event), [])
+    return hooks
 
 
 def list_all_hooks():
